%bcond_with tex
%bcond_with system_tre
%bcond_with macros
%bcond_with lto

%ifnarch x86_64
%bcond_with tests
%else
%bcond_without tests
%endif

%define add_submodule() %{lua:
  local name = rpm.expand("%1")
  local version = rpm.expand("%2")
  local rpm_version = string.gsub(version, "-", ".")
  print("Provides: R-" .. name .. " = " .. rpm_version .. "\\n")
  print("Provides: R(" .. name .. ") = " .. rpm_version)
}

%define __brp_mangle_shebangs /usr/bin/true
%undefine _package_note_flags
%global _lto_cflags %nil
%global abi_ver %%(echo %{version} | cut -d. -f1-2)

Summary:       A language for data analysis and graphics
Name:          R
Version:       4.4.1
Release:       2%{?dist}
License:       GPL-2.0-or-later
URL:           https://www.r-project.org
Source0:       https://cran.r-project.org/src/base/R-4/R-%{version}.tar.gz

Patch3000:     R-3.3.0-fix-java_path-in-javareconf.patch

BuildRequires: gcc-gfortran gcc-c++ libpng-devel libjpeg-devel libtiff-devel cairo-devel
BuildRequires: pango-devel readline-devel tcl-devel tk-devel ncurses-devel
BuildRequires: pcre2-devel libcurl-devel bzip2-devel xz-devel zlib-devel flexiblas-devel
BuildRequires: libSM-devel libX11-devel libICE-devel libXt-devel libXmu-devel libicu-devel valgrind-devel
BuildRequires: java-devel autoconf automake libtool less
%if %{with system_tre}
BuildRequires: tre-devel
%endif
%if %{with tex}
BuildRequires: tex(latex) texinfo-tex tex(upquote.sty) tex(inconsolata.sty)
%endif

Requires:       R-devel = %{version}-%{release}

%description
This is a metapackage that provides both core R userspace and all R development components.

R is a language and environment for statistical computing and graphics.  R is similar to the
award-winning S system, which was developed at Bell Laboratories by John Chambers et al. It provides
a wide variety of statistical and graphical techniques (linear and nonlinear modelling, statistical
tests, time series analysis, classification, clustering, ...).

R is designed as a true computer language with control-flow constructions for iteration and
alternation, and it allows users to add additional functionality by defining new functions. For
computationally intensive tasks, C, C++ and Fortran code can be linked and called at run time.

%package core
Summary:  The minimal R components necessary for a functional runtime
Requires: libRmath = %{version}-%{release}
Requires: system-rpm-config vim perl sed gawk less make unzip xdg-utils
%if %{with tex}
Requires: tex(latex) tex(dvips)
%endif
Provides:       R(ABI) = %{abi_ver}
Recommends:     cups

%add_submodule  base %{version}
%add_submodule  boot 1.3-30
%add_submodule  class 7.3-22
%add_submodule  cluster 2.1.6
%add_submodule  codetools 0.2-20
%add_submodule  compiler %{version}
%add_submodule  datasets %{version}
%add_submodule  foreign 0.8-86
%add_submodule  graphics %{version}
%add_submodule  grDevices %{version}
%add_submodule  grid %{version}
%add_submodule  KernSmooth 2.23-24
%add_submodule  lattice 0.22-6
%add_submodule  MASS 7.3-60.2
%add_submodule  Matrix 1.7-0
%add_submodule  methods %{version}
%add_submodule  mgcv 1.9-1
%add_submodule  nlme 3.1-164
%add_submodule  nnet 7.3-19
%add_submodule  parallel %{version}
%add_submodule  rpart 4.1.23
%add_submodule  spatial 7.3-17
%add_submodule  splines %{version}
%add_submodule  stats %{version}
%add_submodule  stats4 %{version}
%add_submodule  survival 3.6-4
%add_submodule  tcltk %{version}
%add_submodule  tools %{version}
%add_submodule  translations %{version}
%add_submodule  utils %{version}

%description core
A language and environment for statistical computing and graphics.  R is similar to the
award-winning S system, which was developed at Bell Laboratories by John Chambers et al. It provides
a wide variety of statistical and graphical techniques (linear and nonlinear modelling, statistical
tests, time series analysis, classification, clustering, ...).

R is designed as a true computer language with control-flow constructions for iteration and
alternation, and it allows users to add additional functionality by defining new functions. For
computationally intensive tasks, C, C++ and Fortran code can be linked and called at run time.

%package core-devel
Summary:  Core files for development of R packages (no Java)
Requires: R-core = %{version}-%{release}
Requires: libRmath-devel = %{version}-%{release} gcc-gfortran gcc-c++ pkgconfig tcl-devel
Requires: tk-devel pcre2-devel bzip2-devel xz-devel zlib-devel flexiblas-devel libX11-devel libicu-devel
%if %{with system_tre}
Requires: tre-devel
%endif
%if %{with tex}
Requires: tex(latex) texinfo-tex tex(ecrm1000.tfm) tex(ptmr8t.tfm) tex(ptmb8t.tfm) tex(inconsolata.sty) qpdf
Requires: tex(pcrr8t.tfm) tex(phvr8t.tfm) tex(ptmri8t.tfm) tex(ptmro8t.tfm) tex(cm-super-ts1.enc)
%endif
Provides: R-Matrix-devel = 1.7.0

%description core-devel
Install R-core-devel if you are going to develop or compile R packages.  This package does not
configure the R environment for Java, install R-java-devel if you want this.

%package devel
Summary:        Full R development environment metapackage
Requires: R-core-devel = %{version}-%{release} R-java-devel = %{version}-%{release}
%if %{with macros}
Requires: R-rpm-macros
%endif

%description devel
This is a metapackage to install a complete (with Java) R development environment.

%package java
Summary:        Java Runtime Environment
Requires(post): R-core = %{version}-%{release}
Requires:       java-headless

%description java
A language and environment for statistical computing and graphics.  R is similar to the
award-winning S system, which was developed at Bell Laboratories by John Chambers et al. It provides
a wide variety of statistical and graphical techniques (linear and nonlinear modelling, statistical
tests, time series analysis, classification, clustering, ...).

R is designed as a true computer language with control-flow constructions for iteration and
alternation, and it allows users to add additional functionality by defining new functions. For
computationally intensive tasks, C, C++ and Fortran code can be linked and called at run time.

This package also has an additional dependency on java

%package java-devel
Summary:        Development package for use with Java enabled R components
Requires:       R-java = %{version}-%{release}
Requires(post): R-core-devel = %{version}-%{release}
Requires(post): java-devel

%description java-devel
Install R-java-devel if you are going to develop or compile R packages that assume java is present
and configured on the system.

%package -n libRmath
Summary:        Standalone math library from the R project

%description -n libRmath
A standalone library of mathematical and statistical functions derived from the R project.  This
package provides the shared libRmath library.

%package -n libRmath-devel
Summary:        Headers from the R Standalone math library
Requires:       libRmath = %{version}-%{release} pkgconfig

%description -n libRmath-devel
A standalone library of mathematical and statistical functions derived from the R project.  This
package provides the libRmath header files.

%package -n libRmath-static
Summary:        Static R Standalone math library
Requires:       libRmath-devel = %{version}-%{release}

%description -n libRmath-static
A standalone library of mathematical and statistical functions derived from the R project.  This
package provides the static libRmath library.

%prep
%autosetup -n %{name}-%{version} -p1

%build
sed -i -e '/R_LIBS_SITE=/s/^/#/g' etc/Renviron.in
echo 'R_LIBS_SITE=${R_LIBS_SITE-'"'/usr/local/lib/R/site-library:/usr/local/lib/R/library:%{_libdir}/R/library:%{_datadir}/R/library'"'}' >> etc/Renviron.in
export R_RD4PDF="times,hyper"
sed -i 's|inconsolata,||g' etc/Renviron.in
export R_PDFVIEWER="%{_bindir}/xdg-open"
export R_PRINTCMD="lpr"
export R_BROWSER="%{_bindir}/xdg-open"
export JAVA_HOME=%{_jvmdir}/jre

%configure \
    rdocdir=%{_pkgdocdir} \
    rincludedir=%{_includedir}/R \
    rsharedir=%{_datadir}/R \
    --with-system-valgrind-headers \
    --with-lapack=flexiblas \
    --with-blas=flexiblas \
    --with-tcl-config=%{_libdir}/tclConfig.sh \
    --with-tk-config=%{_libdir}/tkConfig.sh \
    --enable-R-shlib \
    --enable-prebuilt-html \
    --enable-R-profiling \
    --enable-memory-profiling \
%if %{with system_tre}
    --with-system-tre \
%endif
%if %{with lto}
    --enable-lto \
%endif
  | tee CONFIGURE.log
cat CONFIGURE.log | grep -A30 'R is now' - > CAPABILITIES
make V=1
(cd src/nmath/standalone; make)

%if %{with tex}
make pdf
make compact-pdf
make info

for i in doc/manual/R-intro.info doc/manual/R-FAQ.info doc/FAQ doc/manual/R-admin.info doc/manual/R-exts.info-1; do
  iconv -f iso-8859-1 -t utf-8 -o $i{.utf8,}
  mv $i{.utf8,}
done
%endif

%install
%if %{with tex}
make DESTDIR=%{buildroot} install install-pdf install-info
%else
make DESTDIR=%{buildroot} install
%endif

rm -f %{buildroot}%{_infodir}/dir
mkdir -p %{buildroot}%{_pkgdocdir}
install -p CAPABILITIES %{buildroot}%{_pkgdocdir}

(cd src/nmath/standalone; %make_install)

mkdir -p %{buildroot}/etc/ld.so.conf.d
echo "%{_libdir}/R/lib" > %{buildroot}/etc/ld.so.conf.d/%{name}-%{_arch}.conf

mkdir -p %{buildroot}%{_datadir}/R/library

touch -r README %{buildroot}%{_pkgdocdir}/CAPABILITIES
touch -r README doc/manual/*.pdf
touch -r README %{buildroot}%{_bindir}/R

# do not support html
rm -rf %{buildroot}%{_pkgdocdir}/html/
rm -rf %{buildroot}%{_libdir}/R/library/*/html

chmod +x %{buildroot}%{_datadir}/R/sh/echo.sh
chmod +x %{buildroot}%{_libdir}/R/bin/*
chmod -x %{buildroot}%{_libdir}/R/library/mgcv/CITATION %{buildroot}%{_pkgdocdir}/CAPABILITIES

if [ ! -d "%{buildroot}%{_libdir}/R/include" ]; then
    pushd %{buildroot}%{_libdir}/R
    ln -s ../../include/R include
    popd
fi

%if %{with tex}
if [ ! -d "%{buildroot}%{_datadir}/texmf/tex/latex/R" ]; then
    mkdir -p %{buildroot}%{_datadir}/texmf/tex/latex
    pushd %{buildroot}%{_datadir}/texmf/tex/latex
    ln -s %{_datadir}/R/texmf/tex/latex R
    popd
fi
%endif

%check
%if %{with tests}
ulimit -s 16384
TZ="Europe/Paris" make check
%endif

%postun core
if [ $1 -eq 0 ] ; then
    /usr/bin/mktexlsr %{_datadir}/texmf &>/dev/null || :
fi

%posttrans core
/usr/bin/mktexlsr %{_datadir}/texmf &>/dev/null || :


%files
# blank package

%files core
%{_bindir}/R
%{_bindir}/Rscript
%{_datadir}/R/
%if %{with tex}
%{_datadir}/texmf/tex/latex/R
%endif
%dir %{_libdir}/R/
%{_libdir}/R/bin/
%dir %{_libdir}/R/etc
%config %{_libdir}/R/etc/Makeconf
%config %{_libdir}/R/etc/javaconf
%config(noreplace) %{_libdir}/R/etc/Renviron
%config(noreplace) %{_libdir}/R/etc/ldpaths
%config(noreplace) %{_libdir}/R/etc/repositories
%{_libdir}/R/lib/
%dir %{_libdir}/R/library/
%dir %{_libdir}/R/library/translations/
%{_libdir}/R/library/translations/DESCRIPTION
%lang(ar) %{_libdir}/R/library/translations/ar/
%lang(bn) %{_libdir}/R/library/translations/bn/
%lang(ca) %{_libdir}/R/library/translations/ca/
%lang(da) %{_libdir}/R/library/translations/da/
%lang(de) %{_libdir}/R/library/translations/de/
%lang(en) %{_libdir}/R/library/translations/en*/
%lang(es) %{_libdir}/R/library/translations/es/
%lang(fa) %{_libdir}/R/library/translations/fa/
%lang(fr) %{_libdir}/R/library/translations/fr/
%lang(hi) %{_libdir}/R/library/translations/hi/
%lang(hu) %{_libdir}/R/library/translations/hu/
%lang(id) %{_libdir}/R/library/translations/id/
%lang(it) %{_libdir}/R/library/translations/it/
%lang(ja) %{_libdir}/R/library/translations/ja/
%lang(ko) %{_libdir}/R/library/translations/ko/
%lang(lt) %{_libdir}/R/library/translations/lt/
%lang(ne) %{_libdir}/R/library/translations/ne/
%lang(nn) %{_libdir}/R/library/translations/nn/
%lang(pl) %{_libdir}/R/library/translations/pl/
%lang(pt) %{_libdir}/R/library/translations/pt*/
%lang(ru) %{_libdir}/R/library/translations/ru/
%lang(sq) %{_libdir}/R/library/translations/sq/
%lang(tr) %{_libdir}/R/library/translations/tr/
%lang(ur) %{_libdir}/R/library/translations/ur/
%lang(zh) %{_libdir}/R/library/translations/zh*/
%{_libdir}/R/library/base/
%dir %{_libdir}/R/library/boot/
%{_libdir}/R/library/boot/bd.q
%{_libdir}/R/library/boot/CITATION
%{_libdir}/R/library/boot/data/
%{_libdir}/R/library/boot/DESCRIPTION
%{_libdir}/R/library/boot/help/
%{_libdir}/R/library/boot/INDEX
%{_libdir}/R/library/boot/Meta/
%{_libdir}/R/library/boot/NAMESPACE
%dir %{_libdir}/R/library/boot/po/
%lang(de) %{_libdir}/R/library/boot/po/de/
%lang(en) %{_libdir}/R/library/boot/po/en*/
%lang(fr) %{_libdir}/R/library/boot/po/fr/
%lang(it) %{_libdir}/R/library/boot/po/it/
%lang(ko) %{_libdir}/R/library/boot/po/ko/
%lang(pl) %{_libdir}/R/library/boot/po/pl/
%lang(ru) %{_libdir}/R/library/boot/po/ru/
%{_libdir}/R/library/boot/R/
%dir %{_libdir}/R/library/class/
%{_libdir}/R/library/class/CITATION
%{_libdir}/R/library/class/DESCRIPTION
%{_libdir}/R/library/class/help/
%{_libdir}/R/library/class/INDEX
%{_libdir}/R/library/class/libs/
%{_libdir}/R/library/class/Meta/
%{_libdir}/R/library/class/NAMESPACE
%{_libdir}/R/library/class/NEWS
%dir %{_libdir}/R/library/class/po/
%lang(de) %{_libdir}/R/library/class/po/de/
%lang(en) %{_libdir}/R/library/class/po/en*/
%lang(fr) %{_libdir}/R/library/class/po/fr/
%lang(it) %{_libdir}/R/library/class/po/it/
%lang(ko) %{_libdir}/R/library/class/po/ko/
%lang(pl) %{_libdir}/R/library/class/po/pl/
%{_libdir}/R/library/class/R/
%dir %{_libdir}/R/library/cluster/
%{_libdir}/R/library/cluster/CITATION
%{_libdir}/R/library/cluster/data/
%{_libdir}/R/library/cluster/DESCRIPTION
%{_libdir}/R/library/cluster/help/
%{_libdir}/R/library/cluster/INDEX
%{_libdir}/R/library/cluster/libs/
%{_libdir}/R/library/cluster/Meta/
%{_libdir}/R/library/cluster/NAMESPACE
%{_libdir}/R/library/cluster/NEWS.Rd
%{_libdir}/R/library/cluster/R/
%{_libdir}/R/library/cluster/test-tools.R
%dir %{_libdir}/R/library/cluster/po/
%lang(de) %{_libdir}/R/library/cluster/po/de/
%lang(en) %{_libdir}/R/library/cluster/po/en*/
%lang(fr) %{_libdir}/R/library/cluster/po/fr/
%lang(it) %{_libdir}/R/library/cluster/po/it/
%lang(ko) %{_libdir}/R/library/cluster/po/ko/
%lang(lt) %{_libdir}/R/library/cluster/po/lt/
%lang(pl) %{_libdir}/R/library/cluster/po/pl/
%dir %{_libdir}/R/library/codetools/
%{_libdir}/R/library/codetools/DESCRIPTION
%{_libdir}/R/library/codetools/help/
%{_libdir}/R/library/codetools/INDEX
%{_libdir}/R/library/codetools/Meta/
%{_libdir}/R/library/codetools/NAMESPACE
%{_libdir}/R/library/codetools/R/
%{_libdir}/R/library/compiler/
%{_libdir}/R/library/datasets/
%dir %{_libdir}/R/library/foreign/
%{_libdir}/R/library/foreign/COPYRIGHTS
%{_libdir}/R/library/foreign/DESCRIPTION
%{_libdir}/R/library/foreign/files/
%{_libdir}/R/library/foreign/help/
%{_libdir}/R/library/foreign/INDEX
%{_libdir}/R/library/foreign/libs/
%{_libdir}/R/library/foreign/Meta/
%{_libdir}/R/library/foreign/NAMESPACE
%dir %{_libdir}/R/library/foreign/po/
%lang(de) %{_libdir}/R/library/foreign/po/de/
%lang(en) %{_libdir}/R/library/foreign/po/en*/
%lang(fr) %{_libdir}/R/library/foreign/po/fr/
%lang(it) %{_libdir}/R/library/foreign/po/it/
%lang(pl) %{_libdir}/R/library/foreign/po/pl/
%{_libdir}/R/library/foreign/R/
%{_libdir}/R/library/graphics/
%{_libdir}/R/library/grDevices
%{_libdir}/R/library/grid/
%dir %{_libdir}/R/library/KernSmooth/
%{_libdir}/R/library/KernSmooth/DESCRIPTION
%{_libdir}/R/library/KernSmooth/help/
%{_libdir}/R/library/KernSmooth/INDEX
%{_libdir}/R/library/KernSmooth/libs/
%{_libdir}/R/library/KernSmooth/Meta/
%{_libdir}/R/library/KernSmooth/NAMESPACE
%dir %{_libdir}/R/library/KernSmooth/po/
%lang(de) %{_libdir}/R/library/KernSmooth/po/de/
%lang(en) %{_libdir}/R/library/KernSmooth/po/en*/
%lang(fr) %{_libdir}/R/library/KernSmooth/po/fr/
%lang(it) %{_libdir}/R/library/KernSmooth/po/it/
%lang(ko) %{_libdir}/R/library/KernSmooth/po/ko/
%lang(pl) %{_libdir}/R/library/KernSmooth/po/pl/
%{_libdir}/R/library/KernSmooth/R/
%dir %{_libdir}/R/library/lattice/
%{_libdir}/R/library/lattice/CITATION
%{_libdir}/R/library/lattice/data/
%{_libdir}/R/library/lattice/demo/
%{_libdir}/R/library/lattice/DESCRIPTION
%{_libdir}/R/library/lattice/help/
%{_libdir}/R/library/lattice/INDEX
%{_libdir}/R/library/lattice/libs/
%{_libdir}/R/library/lattice/Meta/
%{_libdir}/R/library/lattice/NAMESPACE
%{_libdir}/R/library/lattice/NEWS.md
%{_libdir}/R/library/lattice/doc
%dir %{_libdir}/R/library/lattice/po/
%lang(de) %{_libdir}/R/library/lattice/po/de/
%lang(en) %{_libdir}/R/library/lattice/po/en*/
%lang(fr) %{_libdir}/R/library/lattice/po/fr/
%lang(it) %{_libdir}/R/library/lattice/po/it/
%lang(ko) %{_libdir}/R/library/lattice/po/ko/
%lang(pl) %{_libdir}/R/library/lattice/po/pl*/
%{_libdir}/R/library/lattice/R/
%dir %{_libdir}/R/library/MASS/
%{_libdir}/R/library/MASS/CITATION
%{_libdir}/R/library/MASS/data/
%{_libdir}/R/library/MASS/DESCRIPTION
%{_libdir}/R/library/MASS/help/
%{_libdir}/R/library/MASS/INDEX
%{_libdir}/R/library/MASS/libs/
%{_libdir}/R/library/MASS/Meta/
%{_libdir}/R/library/MASS/NAMESPACE
%{_libdir}/R/library/MASS/NEWS
%dir %{_libdir}/R/library/MASS/po
%lang(de) %{_libdir}/R/library/MASS/po/de/
%lang(en) %{_libdir}/R/library/MASS/po/en*/
%lang(fr) %{_libdir}/R/library/MASS/po/fr/
%lang(it) %{_libdir}/R/library/MASS/po/it/
%lang(ko) %{_libdir}/R/library/MASS/po/ko/
%lang(pl) %{_libdir}/R/library/MASS/po/pl/
%{_libdir}/R/library/MASS/R/
%{_libdir}/R/library/MASS/scripts/
%dir %{_libdir}/R/library/Matrix/
%{_libdir}/R/library/Matrix/data/
%{_libdir}/R/library/Matrix/doc/
%{_libdir}/R/library/Matrix/DESCRIPTION
%{_libdir}/R/library/Matrix/external/
%{_libdir}/R/library/Matrix/help/
%{_libdir}/R/library/Matrix/include/
%{_libdir}/R/library/Matrix/INDEX
%{_libdir}/R/library/Matrix/libs/
%{_libdir}/R/library/Matrix/LICENCE
%{_libdir}/R/library/Matrix/Meta/
%{_libdir}/R/library/Matrix/NAMESPACE
%{_libdir}/R/library/Matrix/NEWS.Rd
%dir %{_libdir}/R/library/Matrix/po/
%lang(de) %{_libdir}/R/library/Matrix/po/de/
%lang(en) %{_libdir}/R/library/Matrix/po/en*/
%lang(fr) %{_libdir}/R/library/Matrix/po/fr/
%lang(it) %{_libdir}/R/library/Matrix/po/it/
%lang(ko) %{_libdir}/R/library/Matrix/po/ko/
%lang(lt) %{_libdir}/R/library/Matrix/po/lt/
%lang(pl) %{_libdir}/R/library/Matrix/po/pl/
%{_libdir}/R/library/Matrix/R/
%{_libdir}/R/library/Matrix/test-tools.R
%{_libdir}/R/library/Matrix/test-tools-1.R
%{_libdir}/R/library/Matrix/test-tools-Matrix.R
%{_libdir}/R/library/Matrix/scripts/
%{_libdir}/R/library/methods/
%{_libdir}/R/library/mgcv/
%dir %{_libdir}/R/library/nlme/
%{_libdir}/R/library/nlme/CITATION
%{_libdir}/R/library/nlme/data/
%{_libdir}/R/library/nlme/DESCRIPTION
%{_libdir}/R/library/nlme/help/
%{_libdir}/R/library/nlme/INDEX
%{_libdir}/R/library/nlme/libs/
%{_libdir}/R/library/nlme/Meta/
%{_libdir}/R/library/nlme/mlbook/
%{_libdir}/R/library/nlme/NAMESPACE
%dir %{_libdir}/R/library/nlme/po/
%lang(de) %{_libdir}/R/library/nlme/po/de/
%lang(en) %{_libdir}/R/library/nlme/po/en*/
%lang(fr) %{_libdir}/R/library/nlme/po/fr/
%lang(ko) %{_libdir}/R/library/nlme/po/ko/
%lang(pl) %{_libdir}/R/library/nlme/po/pl/
%{_libdir}/R/library/nlme/R/
%{_libdir}/R/library/nlme/scripts/
%dir %{_libdir}/R/library/nnet/
%{_libdir}/R/library/nnet/CITATION
%{_libdir}/R/library/nnet/DESCRIPTION
%{_libdir}/R/library/nnet/help/
%{_libdir}/R/library/nnet/INDEX
%{_libdir}/R/library/nnet/libs/
%{_libdir}/R/library/nnet/Meta/
%{_libdir}/R/library/nnet/NAMESPACE
%{_libdir}/R/library/nnet/NEWS
%dir %{_libdir}/R/library/nnet/po
%lang(de) %{_libdir}/R/library/nnet/po/de/
%lang(en) %{_libdir}/R/library/nnet/po/en*/
%lang(fr) %{_libdir}/R/library/nnet/po/fr/
%lang(it) %{_libdir}/R/library/nnet/po/it/
%lang(ko) %{_libdir}/R/library/nnet/po/ko/
%lang(pl) %{_libdir}/R/library/nnet/po/pl/
%{_libdir}/R/library/nnet/R/
%{_libdir}/R/library/parallel/
%dir %{_libdir}/R/library/rpart/
%{_libdir}/R/library/rpart/data/
%{_libdir}/R/library/rpart/DESCRIPTION
%{_libdir}/R/library/rpart/doc/
%{_libdir}/R/library/rpart/help/
%{_libdir}/R/library/rpart/INDEX
%{_libdir}/R/library/rpart/libs/
%{_libdir}/R/library/rpart/Meta/
%{_libdir}/R/library/rpart/NAMESPACE
%{_libdir}/R/library/rpart/NEWS.Rd
%dir %{_libdir}/R/library/rpart/po
%lang(de) %{_libdir}/R/library/rpart/po/de/
%lang(en) %{_libdir}/R/library/rpart/po/en*/
%lang(fr) %{_libdir}/R/library/rpart/po/fr/
%lang(ko) %{_libdir}/R/library/rpart/po/ko/
%lang(pl) %{_libdir}/R/library/rpart/po/pl/
%lang(ru) %{_libdir}/R/library/rpart/po/ru/
%{_libdir}/R/library/rpart/R/
%dir %{_libdir}/R/library/spatial/
%{_libdir}/R/library/spatial/CITATION
%{_libdir}/R/library/spatial/DESCRIPTION
%{_libdir}/R/library/spatial/help/
%{_libdir}/R/library/spatial/INDEX
%{_libdir}/R/library/spatial/libs/
%{_libdir}/R/library/spatial/Meta/
%{_libdir}/R/library/spatial/NAMESPACE
%{_libdir}/R/library/spatial/NEWS
%dir %{_libdir}/R/library/spatial/po
%lang(de) %{_libdir}/R/library/spatial/po/de/
%lang(en) %{_libdir}/R/library/spatial/po/en*/
%lang(fr) %{_libdir}/R/library/spatial/po/fr/
%lang(it) %{_libdir}/R/library/spatial/po/it/
%lang(ko) %{_libdir}/R/library/spatial/po/ko/
%lang(pl) %{_libdir}/R/library/spatial/po/pl/
%{_libdir}/R/library/spatial/ppdata/
%{_libdir}/R/library/spatial/PP.files
%{_libdir}/R/library/spatial/R/
%{_libdir}/R/library/splines/
%{_libdir}/R/library/stats/
%{_libdir}/R/library/stats4/
%{_libdir}/R/library/survival/
%{_libdir}/R/library/tcltk/
%{_libdir}/R/library/tools/
%{_libdir}/R/library/utils/
%{_libdir}/R/modules
%{_libdir}/R/COPYING
%{_libdir}/R/SVN-REVISION
%{_mandir}/man1/*
%{_pkgdocdir}
%docdir %{_pkgdocdir}
/etc/ld.so.conf.d/*

%files core-devel
%{_libdir}/pkgconfig/libR.pc
%{_includedir}/R
%{_libdir}/R/include

%files devel
# blank package, all files provided by R-core-devel

%files java
# blank package, all files provided by R-core

%files java-devel
# blank package, all files provided by R-core-devel

%files -n libRmath
%license doc/COPYING
%{_libdir}/libRmath.so

%files -n libRmath-devel
%{_includedir}/Rmath.h
%{_libdir}/pkgconfig/libRmath.pc

%files -n libRmath-static
%{_libdir}/libRmath.a

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.4.1-2
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Wed Aug 28 2024 Upgrade Robot <upbot@opencloudos.tech> - 4.4.1-1
- [Type] Security
- [Desc] Upgrade to version 4.4.1 and fix CVE-2024-27322.

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.3.1-8
- Rebuilt for loongarch release

* Wed Nov 29 2023 Xin Cheng <denisecheng@tencent.com> - 4.3.1-7
- replace opencloudos-rpm-config with system-rpm-config

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 4.3.1-6
- Rebuild for curl-8.4.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.3.1-5
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 rockerzhu <rockerzhu@tencent.com> - 4.3.1-4
- Rebuilt for icu 73.2

* Thu Aug 03 2023 cunshunxia <cunshunxia@tencent.com> - 4.3.1-3
- Rebuilt for tcl 8.6.13

* Wed Aug 02 2023 kianli <kianli@tencent.com> - 4.3.1-2
- Rebuilt for libtiff 4.5.1

* Thu Jul 13 2023 Shuo Wang <abushwang@tencent.com> - 4.3.1-1
- update to 4.3.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.2.3-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.2.3-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 29 2023 Shuo Wang <abushwang@tencent.com> - 4.2.3-1
- initial build
